import {Component} from '@angular/core';
import {App, NavController, AlertController, NavParams} from 'ionic-angular';
import {LoginPage} from '../../login/login';
import {AppGlobal, AppService} from '../../../service/http.service';
import {PersonInfoPage} from '../../mine/person/personInfo/personInfo';
import {MyActivityListPage} from '../../mine/myActivityList/myActivityList';
import {MyReportPage} from '../../mine/myReport/myReport';
import {OperationListPage} from '../../mine/operation-list/operation-list';
import {VersionPage} from '../../version/version';
import {Response} from '@angular/http';
import {Storage} from '@ionic/storage';

import {AppVersion} from '@ionic-native/app-version';
import {AppUpdateService} from "../../../service/appUpdate.service";
import {MyDutyPage} from "../../mine/my-duty/my-duty";
import {MySurveyPage} from "../../home/mySurvey/my-survey/my-survey";


@Component({
    selector: 'page-mine',
    templateUrl: 'mine.html',
})
export class MinePage {

    user: any;
    orgName: '';
    gender: object;
    version: string = '';
    isLatest: boolean = true;
    picture: string = AppGlobal.picture;

    constructor(public navCtrl: NavController,
                private appCtrl: App,
                private alertCtrl: AlertController,
                public navParams: NavParams,
                public appService: AppService,
                public storage: Storage,public app:App,
                private appUpdateService: AppUpdateService,
                private appVersion: AppVersion) {
        this.orgNameInfo();
    }

    ionViewWillEnter() {
        this.getversion();
    }

    orgNameInfo(): void {
        this.user = this.storage.get("user").then((value) => {
            this.user = value;
            this.gender = this.user.userDetail.user.gender;
            this.getOrgName(this.user.id, result => {
                let data = result;
                this.orgName = data["orgName"];
            });
        });
    }

    getOrgName(id, callback?): any {
        this.appService.ObserverHttpPost("/wisdomgroup/app/getOrgName", {"userid": id})
            .toPromise()
            .then(res => {
                var data = res.json();
                callback(data == null ? "[]" : data);
            })
            .catch(error => {
            });
    }

    personInfo() {
        this.navCtrl.push("PersonInfoPage");
    }

    //我的活动
    myActivityList() {
        this.navCtrl.push("MyActivityListPage");
    }

    //我的报备
    myReport() {
        this.navCtrl.push("MyReportPage");
    }

    //操作记录
    myOperationList() {
        this.navCtrl.push("OperationListPage");
    }

    //我的问卷
    mySurvey() {
        this.navCtrl.push('MySurveyPage');
    }

    logout() {
        this.alertCtrl.create({
            message: "确认退出登录？",
            buttons: [
                {
                    text: '取消',
                    role: 'cancel'
                },
                {
                    text: '确定',
                    handler: () => {
                        // this.appService.ObserverHttpGet("/wisdomgroup/app/logout",null)
                        // .subscribe((res: Response) => {
                        //   this.appCtrl.getRootNav().setRoot(LoginPage)
                        //   }, error => {
                        //       this.appService.alert('系统错误！');
                        //   })
                        //退出登陆，将缓存中的用户注销，跳转到登陆页面。
                        this.storage.get("user").then((value) => {
                        });
                        this.storage.remove("user");
                        this.storage.remove("userLoginInfo");
                        this.logoutApp();
                        this.appCtrl.getRootNav().setRoot(LoginPage)
                    }

                }]
        }).present();
    }

    //后台退出
    logoutApp() {
        this.appService.ObserverHttpGet("/wisdomgroup/app/logout", null)
            .subscribe((res: Response) => {
                    let data = res.json();
                }, error => {
                }
            );
    }

    //版本信息
    currentVersion() {
        this.navCtrl.push("VersionPage");
    }

    //获取最新版本信息
    getversion() {
        //检测是否需要更新
        this.appVersion.getVersionNumber().then((version: string) => {
            this.version = version;
            this.appUpdateService.compariVersion().subscribe(data => {
                if (data.code == 200) {
                    if (data.latestVersion != null && data.latestVersion != version) {
                        this.isLatest = false;
                    }
                }
            });
        }).catch(err => {
        });
    }

    goSet() {
        this.app.getRootNav().push('VersionPage');
    }

    goDuty() {
        this.navCtrl.push("MyDutyPage");
    }
}
